/* 
   QTrec.c (C) Justin Schoeman 2001 (justin@suntiger.ee.up.ac.za)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
    
*/
#include <stdio.h>
#include <stdlib.h>
#include <signal.h>

#include "NVrec.h"

int main(int argc, char **argv)
{
	struct cap_core_t * cct;
	struct aud_core_t * audt;
	struct file_core_t * fct;
	char **args;
	
	NV_MODULE;
	NV_USAGE(argc, argv, oss_core, v4lgen_core, qtfile_core);
	
	if(!(args = nvcore_args(argc, argv, NULL))) {
		perror("NVrec: parsing arguments");
		return -1;
	}
	
	if(!(cct = v4lgen_core.cap_core_init(args, qtfile_core.file_core_format(args)))) {
		perror("NVrec: initialising capture device");
		return -1;
	}
	if(!(audt = oss_core.aud_core_init(args, cct->cap_core_ftime(cct)))) {
		perror("NVrec: initialising audio device");
		return -1;	
	}
	if(!(fct = qtfile_core.file_core_init(args, cct->cap_core_ftime(cct)))) {
		perror("NVrec: opening output file");
		return -1;	
	}
	
	nvcore_main(args, cct, audt, fct, 0);
	
	fct->file_core_close(fct);
	cct->cap_core_close(cct);
	audt->aud_core_close(audt);
	nvcore_close(args);
	return 0;
}
